@@ -155,7 +155,7 @@ def apply_from_variant(variant, petri_net, initial_marking, final_marking, param
             pm4pyutil.constants.PARAMETER_CONSTANT_ACTIVITY_KEY]
     trace = log_implementation.Trace()
     variant_delimiter = exec_utils.get_param_value(Parameters.PARAMETER_VARIANT_DELIMITER, parameters,
-                                                   ",")
+                                                   pm4pyutil.constants.DEFAULT_VARIANT_SEP)
     variant_split = variant.split(variant_delimiter) if type(variant) is str else variant
     for i in range(len(variant_split)):
         trace.append(log_implementation.Event({activity_key: variant_split[i]}))
