@@ -1,4 +1,6 @@
-from pm4py.objects.conversion.log import factory as log_conv_factory
+import deprecation
+
+from pm4py.objects.conversion.log import converter as log_converter
 from pm4py.algo.discovery.log_skeleton.versions import classic
 
 CLASSIC = "classic"
@@ -7,7 +9,8 @@ DEFAULT_VARIANT = CLASSIC
 
 VERSIONS = {CLASSIC: classic.apply}
 
-
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Use algorithm entrypoint instead')
 def apply(log, variant=DEFAULT_VARIANT, parameters=None):
     """
     Discover a log skeleton from an event log
@@ -28,4 +31,4 @@ def apply(log, variant=DEFAULT_VARIANT, parameters=None):
     model
         Log skeleton model
     """
-    return VERSIONS[variant](log_conv_factory.apply(log, parameters=parameters), parameters=parameters)
+    return VERSIONS[variant](log_converter.apply(log, parameters=parameters), parameters=parameters)
