@@ -1,8 +1,16 @@
 from pm4py.algo.enhancement.roles.common import algorithm
-from pm4py.objects.conversion.log import factory as log_conv_factory
+from pm4py.objects.conversion.log import converter as log_converter
 from pm4py.util import xes_constants as xes
-from pm4py.util import constants
 from collections import Counter
+from pm4py.util import exec_utils
+from enum import Enum
+from pm4py.util import constants
+
+
+class Parameters(Enum):
+    ROLES_THRESHOLD_PARAMETER = "roles_threshold_parameter"
+    RESOURCE_KEY = constants.PARAMETER_CONSTANT_RESOURCE_KEY
+    ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
 
 
 def apply(log, parameters=None):
@@ -25,11 +33,10 @@ def apply(log, parameters=None):
     if parameters is None:
         parameters = {}
 
-    resource_key = parameters[
-        constants.PARAMETER_CONSTANT_RESOURCE_KEY] if constants.PARAMETER_CONSTANT_RESOURCE_KEY in parameters else xes.DEFAULT_RESOURCE_KEY
-    activity_key = parameters[
-        constants.PARAMETER_CONSTANT_ACTIVITY_KEY] if constants.PARAMETER_CONSTANT_ACTIVITY_KEY in parameters else xes.DEFAULT_NAME_KEY
-    stream = log_conv_factory.apply(log, variant=log_conv_factory.TO_EVENT_STREAM)
+    resource_key = exec_utils.get_param_value(Parameters.RESOURCE_KEY, parameters, xes.DEFAULT_RESOURCE_KEY)
+    activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes.DEFAULT_NAME_KEY)
+
+    stream = log_converter.apply(log, variant=log_converter.TO_EVENT_STREAM)
 
     activity_resource_couples = Counter((event[resource_key], event[activity_key]) for event in stream)
 
