@@ -1,3 +1,5 @@
+import deprecation
+
 from pm4py.objects.log.adapters.pandas import csv_import_adapter as pandas_csv_import_adapter
 from pm4py.objects.log.importer.csv.versions import pandas_df_imp
 from pm4py.objects.log.util import string_to_file
@@ -19,6 +21,8 @@ VERSIONS = {PANDAS: pandas_df_imp.import_event_stream}
 DATAFRAME_MANAGER = {PANDAS: pandas_csv_import_adapter}
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the csv using pandas, then convert it to an event log, if needed')
 def import_dataframe_from_path(path, parameters=None, variant=PANDAS):
     """
     Imports a dataframe from the given path
@@ -56,6 +60,8 @@ def import_dataframe_from_path(path, parameters=None, variant=PANDAS):
                                                                  timest_columns=timest_columns, encoding=encoding)
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the csv using pandas, then convert it to an event log, if needed')
 def import_dataframe_from_path_wo_timeconversion(path, parameters=None, variant=PANDAS):
     """
     Imports a dataframe from the given path (without doing the timestamp columns conversion)
@@ -86,6 +92,8 @@ def import_dataframe_from_path_wo_timeconversion(path, parameters=None, variant=
                                                                                    nrows=nrows, encoding=encoding)
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the csv using pandas, then convert it to an event log, if needed')
 def import_dataframe_from_csv_string(csv_string, parameters=None, variant=PANDAS):
     """
     Import dataframe from CSV string
@@ -125,6 +133,8 @@ def import_dataframe_from_csv_string(csv_string, parameters=None, variant=PANDAS
                                                                        encoding=encoding)
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the csv using pandas, then convert it to an event log, if needed')
 def convert_dataframe_to_stream(dataframe, parameters=None, variant=PANDAS):
     """
     Convert a dataframe to an event stream
@@ -145,12 +155,14 @@ def convert_dataframe_to_stream(dataframe, parameters=None, variant=PANDAS):
     """
     if parameters is None:
         parameters = {}
-    
+
     insert_event_indexes = parameters[INSERT_EVENT_INDEXES] if INSERT_EVENT_INDEXES in parameters else False
 
     return DATAFRAME_MANAGER[variant].convert_dataframe_to_stream(dataframe, insert_event_indexes=insert_event_indexes)
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the csv using pandas, then convert it to an event log, if needed')
 def convert_timestamp_columns_in_df(df, timest_format=None, timest_columns=None, variant=PANDAS):
     """
     Convert all dataframe columns in a dataframe
@@ -176,6 +188,8 @@ def convert_timestamp_columns_in_df(df, timest_format=None, timest_columns=None,
                                                                       timest_columns=timest_columns)
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the csv using pandas, then convert it to an event log, if needed')
 def import_log_from_string(log_string, parameters=None, variant="pandas"):
     """
     Import a CSV log from a string
@@ -204,6 +218,8 @@ def import_log_from_string(log_string, parameters=None, variant="pandas"):
     return import_event_stream(temp_file, parameters=parameters, variant=variant)
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the csv using pandas, then convert it to an event log, if needed')
 def import_event_stream(path, parameters=None, variant="pandas"):
     """
     Import a CSV log into an EventLog object
@@ -231,11 +247,15 @@ def import_event_stream(path, parameters=None, variant="pandas"):
     return VERSIONS[variant](path, parameters=parameters)
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the csv using pandas, then convert it to an event log, if needed')
 def import_event_log(path, parameters=None, variant="pandas"):
     # legacy method, to be removed
     return import_event_stream(path, parameters=parameters, variant="pandas")
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the csv using pandas, then convert it to an event log, if needed')
 def apply(path, parameters=None, variant="pandas"):
     """
     Import a CSV log into an EventLog object
